import java.util.*;

/**
 * Clase que representa un equipo universitario
 */
public class Equipo
{

    private String nombre;
    private Set<Alumno> conj;

    /**
     * Constructor for objects of class Equipo
     */
    public Equipo(String nombre)
    {
        this.nombre=nombre;
        // creamos el equipo con un tamaño 
        // inicial de 50 elementos
        this.conj=new HashSet<Alumno>(50);
    }
    
    /**
     * Retorna el nombre del equipo
     */
    public String nombre() {
        return this.nombre;   
    }

    /**
     *  Insertar un alumno. 
     *  Lanza una excepción si ya pertenece
     */
    public void inserta(Alumno a) throws Repetido
    {
        boolean insertado=conj.add(a);
        if (!insertado) {
            throw new Repetido(a.toString());   
        }
    }
    
    /**
     * Borrar un alumno
     * Lanza una excepción si no pertenece
     */
    public void borra(Alumno a) throws NoExiste
    {
        boolean borrado=conj.remove(a);
        if (!borrado) {
            throw new NoExiste();   
        }
    }

    /**
     * Averiguar la pertenencia de un alumno al equipo
     */
    public boolean contiene(Alumno a)
    {
        return conj.contains(a);
    }
    
    /**
     * Union de equipos
     */
    public Equipo union(Equipo otro) {
        Equipo res=new Equipo(this.nombre+"+"+otro.nombre);
        res.conj=new HashSet<Alumno>(this.conj);
        res.conj.addAll(otro.conj);
        return res;
    }
    
    /**
     * Interseccion de equipos
     */
    public Equipo interseccion(Equipo otro) {
        Equipo res=new Equipo(this.nombre+"*"+otro.nombre);
        res.conj=new HashSet<Alumno>(this.conj);
        res.conj.retainAll(otro.conj);
        return res;
    }
    
    /**
     * Muestra en pantalla el equipo
     */
    public void muestra() {
        System.out.println("-----------------------------");
        System.out.println("Conjunto: "+nombre);
        for(Alumno a: conj) {
            System.out.println(a);
        }
        // Otra forma de hacerlo:
        // System.out.println(conj);
        
        System.out.println(".............................");
    }

}
